@@ -8,29 +8,22 @@
 #   for commercial distribution without the prior approval of the author.
 
 package Algorithm::Permute;
-$Algorithm::Permute::VERSION = '0.12_001'; # TRIAL
+use strict;
+use warnings;
 
-$Algorithm::Permute::VERSION = '0.12001';use strict;
-use vars qw($VERSION @ISA @EXPORT @EXPORT_OK);
+our @ISA = qw(Exporter);
+our @EXPORT_OK = qw(permute);
 
-require Exporter;
-require DynaLoader;
-require AutoLoader;
+our $VERSION = '0.12_002'; # TRIAL VERSION
 
-@ISA = qw(Exporter DynaLoader);
-@EXPORT_OK = qw(permute);
+our $XS_VERSION = $VERSION;
+$VERSION = eval $VERSION;
 
-# Items to export into callers namespace by default. Note: do not export
-# names by default without a very good reason. Use EXPORT_OK instead.
-# Do not simply export all your public functions/methods/constants.
-
-bootstrap Algorithm::Permute $VERSION;
-
-# Preloaded methods go here.
-
-# Autoload methods go after =cut, and are processed by the autosplit program.
+require XSLoader;
+XSLoader::load('Algorithm::Permute', $XS_VERSION);
 
 1;
+
 __END__
 
 =head1 NAME
@@ -171,18 +164,10 @@ The classic way, usually used by Lisp hackers: perldoc perlfaq4
 
 =back
 
-=head1 AUTHOR
-
-Edwin Pratomo, I<edpratomo@cpan.org>. 
-
-The object oriented interface is taken from Tom Phoenix's C<List::Permutor>.
-Robin Houston <robin@kitsite.com> invented and contributed the callback
-style interface.
-
 =head1 ACKNOWLEDGEMENT
 
-Yustina Sri Suharini - my ex-fiance-now-wife, for providing the permutation
-problem to me.
+In Edwin's words: Yustina Sri Suharini - my ex-fiance-now-wife, for
+providing the permutation problem to me.
 
 =head1 SEE ALSO
 
@@ -195,4 +180,20 @@ Korsh and Garrett
 
 =back
 
+=head1 AUTHOR
+
+Edwin Pratomo <edpratomo@cpan.org> was the original author.
+
+Stephan Loyd <sloyd@cpan.org> is co-maintainer.
+
+The object oriented interface is taken from Tom Phoenix's C<List::Permutor>.
+Robin Houston <robin@kitsite.com> invented and contributed the callback
+style interface.
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 1999 by Edwin Pratomo.
+
+This is free software; you can redistribute it and/or modify it under the same terms as the Perl 5 programming language system itself.
+
 =cut
